Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Decode ¶
Decode returns the bytes represented by the hexadecimal string s.
Decode expects that s contains only hexadecimal characters and that s has even length. If the input is malformed, Decode returns the bytes decoded before the error.
func DecodedLen ¶
DecodedLen returns the length of a decoding of x source bytes. Specifically, it returns x / 2.
func Dump ¶
Dump returns a string that contains a hex dump of the given data. The format of the hex dump matches the output of `hexdump -C` on the command line.
func EncodedLen ¶
EncodedLen returns the length of an encoding of n source bytes. Specifically, it returns n * 2.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.